@@ -16,18 +16,28 @@ class InstaClientError(Exception):
         return f'{self.message}'
 
 
+class InvalidDriverPathError(InstaClientError):
+    """Raised when trying to initialize an InstaClient object on a localhost with an unexisting driver Path.
+
+    Args:
+        driver_path
+    """
+    def __init__(self, driver_path):
+        self.driver_path = driver_path
+        super().__init__(message='No driver was found in the indicated path')
+
+    def __str__(self):
+        return f'{self.driver_path} -> {self.message}'
+
+
+
 class InvaildHostError(InstaClientError):
     """Raised when trying to pass an incorrect host index in InstaClient.__init__()
 
     Args:
         host_int:int: The driver int variable passed to InstaClient()
     """
-    def __init__(self, host_int:int):
-        self.host_int = host_int
-        super().__init__(message='This integer does not refer to any host')
-
-    def __str__(self):
-        return f'{self.host_int} -> {self.message}'
+    
 
 
 class InvaildDriverError(InstaClientError):
